from setuptools import setup

setup(name='thjo_distributions',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['thjo_distributions'],
      author = 'Jonas Theiler',
      author_email = 'someemail@something.com',
      zip_safe=False)
